@@ -6,34 +6,12 @@ Configuration for Sphinx.
 # pylint: disable=invalid-name
 
 import datetime
-import logging
-from typing import Dict, Iterable
 
-import sphinx_autodoc_typehints
 from pkg_resources import get_distribution
 
 project = 'VWS-Python'
 author = 'Adam Dangoor'
 
-
-# sphinx_autodoc_typehints has a problem with dataclasses.
-# See https://github.com/agronholm/sphinx-autodoc-typehints/issues/123.
-#
-# The logger emits a warning, which is shown in Sphinx as an error as we use
-# -W to show warnings as errors.
-#
-# We want to ignore that error while the bug is open, and therefore we turn
-# that one warning into an info message.
-def _custom_warning_handler(msg: str, *args: Iterable, **kwargs: Dict) -> None:
-    level = logging.WARNING
-    if 'Cannot treat a function defined as a local function' in msg:
-        level = logging.INFO
-
-    sphinx_autodoc_typehints.logger.log(level, msg, *args, **kwargs)
-
-
-sphinx_autodoc_typehints.logger.warning = _custom_warning_handler
-
 extensions = [
     'sphinx.ext.autodoc',
     'sphinx.ext.intersphinx',
@@ -83,7 +61,7 @@ html_sidebars = {
 htmlhelp_basename = 'VWSPYTHONdoc'
 autoclass_content = 'init'
 intersphinx_mapping = {
-    'python': ('https://docs.python.org/3.7', None),
+    'python': ('https://docs.python.org/3.9', None),
 }
 nitpicky = True
 warning_is_error = True
