@@ -2,12 +2,14 @@
 Tools for interacting with Vuforia APIs.
 """
 
+from __future__ import annotations
+
 import base64
 import io
 import json
 from datetime import date
 from time import sleep
-from typing import Dict, List, Optional, Union
+from typing import Dict
 from urllib.parse import urljoin
 
 import requests
@@ -154,6 +156,9 @@ class VWS:
                 HTML page with the text "Oops, an error occurred". This has
                 been seen to happen when the given name includes a bad
                 character.
+            json.decoder.JSONDecodeError: The server did not respond with valid
+                JSON. This may happen if the server address is not a valid
+                Vuforia server.
         """
         response = _target_api_request(
             server_access_key=self._server_access_key,
@@ -164,11 +169,10 @@ class VWS:
             base_vws_url=self._base_vws_url,
         )
 
-        try:
-            result_code = response.json()['result_code']
-        except json.decoder.JSONDecodeError as exc:
-            assert 'Oops' in response.text, response.text
-            raise UnknownVWSErrorPossiblyBadName() from exc
+        if 'Oops, an error occurred' in response.text:
+            raise UnknownVWSErrorPossiblyBadName
+
+        result_code = response.json()['result_code']
 
         if result_code == expected_result_code:
             return response
@@ -197,10 +201,10 @@ class VWS:
     def add_target(
         self,
         name: str,
-        width: Union[int, float],
+        width: int | float,
         image: io.BytesIO,
         active_flag: bool,
-        application_metadata: Optional[str],
+        application_metadata: str | None,
     ) -> str:
         """
         Add a target to a Vuforia Web Services database.
@@ -355,7 +359,7 @@ class VWS:
         self,
         target_id: str,
         seconds_between_requests: float = 0.2,
-        timeout_seconds: Optional[float] = 60 * 5,
+        timeout_seconds: float | None = 60 * 5,
     ) -> None:
         """
         Wait up to five minutes (arbitrary) for a target to get past the
@@ -399,7 +403,7 @@ class VWS:
         except FunctionTimedOut as exc:
             raise TargetProcessingTimeout from exc
 
-    def list_targets(self) -> List[str]:
+    def list_targets(self) -> list[str]:
         """
         List target IDs.
 
@@ -544,7 +548,7 @@ class VWS:
             expected_result_code='Success',
         )
 
-    def get_duplicate_targets(self, target_id: str) -> List[str]:
+    def get_duplicate_targets(self, target_id: str) -> list[str]:
         """
         Get targets which may be considered duplicates of a given target.
 
@@ -582,11 +586,11 @@ class VWS:
     def update_target(
         self,
         target_id: str,
-        name: Optional[str] = None,
-        width: Optional[Union[int, float]] = None,
-        image: Optional[io.BytesIO] = None,
-        active_flag: Optional[bool] = None,
-        application_metadata: Optional[str] = None,
+        name: str | None = None,
+        width: int | float | None = None,
+        image: io.BytesIO | None = None,
+        active_flag: bool | None = None,
+        application_metadata: str | None = None,
     ) -> None:
         """
         Add a target to a Vuforia Web Services database.
@@ -629,7 +633,7 @@ class VWS:
             ~vws.exceptions.vws_exceptions.RequestTimeTooSkewed: There is an
                 error with the time sent to Vuforia.
         """
-        data: Dict[str, Union[str, bool, float, int]] = {}
+        data: Dict[str, str | bool | float | int] = {}
 
         if name is not None:
             data['name'] = name
